pub struct PartitionEntry {
pub name: String,
pub type_guid: Guid,
pub instance_guid: Guid,
pub start_block: u64,
pub num_blocks: u64,
pub flags: u64,
}Expand description
Describes a partition entry for use with PartitionsAdmin.ResetPartitionTable.
Fields
name: Stringtype_guid: Guidinstance_guid: Guidstart_block: u64num_blocks: u64flags: u64Trait Implementations
Sourceimpl Clone for PartitionEntry
impl Clone for PartitionEntry
Sourcefn clone(&self) -> PartitionEntry
fn clone(&self) -> PartitionEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PartitionEntry
impl Debug for PartitionEntry
Sourceimpl<D> Decode<PartitionEntry, D> for PartitionEntrywhere
D: ResourceDialect,
impl<D> Decode<PartitionEntry, D> for PartitionEntrywhere
D: ResourceDialect,
Sourcefn new_empty() -> PartitionEntry
fn new_empty() -> PartitionEntry
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<PartitionEntry, D> for &PartitionEntrywhere
D: ResourceDialect,
impl<D> Encode<PartitionEntry, D> for &PartitionEntrywhere
D: ResourceDialect,
Sourceimpl PartialEq for PartitionEntry
impl PartialEq for PartitionEntry
Sourcefn eq(&self, other: &PartitionEntry) -> bool
fn eq(&self, other: &PartitionEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for PartitionEntry
impl StructuralPartialEq for PartitionEntry
Sourceimpl TypeMarker for PartitionEntry
impl TypeMarker for PartitionEntry
Sourcetype Owned = PartitionEntry
type Owned = PartitionEntry
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for PartitionEntry
impl ValueTypeMarker for PartitionEntry
Sourcetype Borrowed<'a> = &'a PartitionEntry
type Borrowed<'a> = &'a PartitionEntry
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<PartitionEntry as TypeMarker>::Owned,
) -> <PartitionEntry as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<PartitionEntry as TypeMarker>::Owned, ) -> <PartitionEntry as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for PartitionEntry
impl RefUnwindSafe for PartitionEntry
impl Send for PartitionEntry
impl Sync for PartitionEntry
impl Unpin for PartitionEntry
impl UnsafeUnpin for PartitionEntry
impl UnwindSafe for PartitionEntry